import UIAbility from "@ohos:app.ability.UIAbility";
import type AbilityConstant from "@ohos:app.ability.AbilityConstant";
import type Want from "@ohos:app.ability.Want";
import hilog from "@ohos:hilog";
import type window from "@ohos:window";
import { QQOpenApiHolder } from "@normalized:N&&&entry/src/main/ets/util/QQOpenApiHolder&";
import type { BusinessError } from "@ohos:base";
import JSON from "@ohos:util.json";
export default class EntryAbility extends UIAbility {
    onCreate(want: Want, launchParam: AbilityConstant.LaunchParam): void {
        hilog.info(0x0000, 'testTag', '%{public}s', 'Ability onCreate');
        QQOpenApiHolder.create();
    }
    onNewWant(want: Want, launchParam: AbilityConstant.LaunchParam): void {
        super.onNewWant(want, launchParam);
        hilog.info(0x0000, 'testTag', "onNewWant want: " + JSON.stringify(want));
        QQOpenApiHolder.getInstance()?.handleResult(want);
    }
    onDestroy(): void {
        hilog.info(0x0000, 'testTag', '%{public}s', 'Ability onDestroy');
    }
    onWindowStageCreate(windowStage: window.WindowStage): void {
        // Main window is created, set main page for this ability
        hilog.info(0x0000, 'testTag', '%{public}s', 'Ability onWindowStageCreate');
        this.setFullScreen(windowStage);
        windowStage.loadContent("pages/Index", (err: BusinessError) => {
            let errCode: number = err.code;
            if (errCode) {
                console.error('Failed to load the content. Cause:' + JSON.stringify(err));
                return;
            }
            console.info('Succeeded in loading the content.');
        });
    }
    private setFullScreen(windowStage: window.WindowStage) {
        // 1.获取应用主窗口。
        let windowClass: window.Window | null = null;
        windowStage.getMainWindow((err: BusinessError, data) => {
            let errCode: number = err.code;
            if (errCode) {
                console.error('Failed to obtain the main window. Cause: ' + JSON.stringify(err));
                return;
            }
            windowClass = data;
            console.info('Succeeded in obtaining the main window. Data: ' + JSON.stringify(data));
            // 实现沉浸式效果。
            let fullScreenType: number = 2;
            if (fullScreenType == 1) { // 方式一：设置导航栏、状态栏不显示。
                let names: Array<'status' | 'navigation'> = [];
                windowClass.setWindowSystemBarEnable(names, (err: BusinessError) => {
                    let errCode: number = err.code;
                    if (errCode) {
                        console.error('Failed to set the system bar to be visible. Cause:' + JSON.stringify(err));
                        return;
                    }
                    console.info('Succeeded in setting the system bar to be visible.');
                });
            }
            else if (fullScreenType == 2) { // 方式二：设置窗口为全屏布局，配合设置导航栏、状态栏的透明度、背景/文字颜色及高亮图标等属性，与主窗口显示保持协调一致。
                let isLayoutFullScreen = true;
                windowClass.setWindowLayoutFullScreen(isLayoutFullScreen, (err: BusinessError) => {
                    let errCode: number = err.code;
                    if (errCode) {
                        console.error('Failed to set the window layout to full-screen mode. Cause:' + JSON.stringify(err));
                        return;
                    }
                    console.info('Succeeded in setting the window layout to full-screen mode.');
                });
                let sysBarProps: window.SystemBarProperties = {
                    // statusBarColor: '#ff00ff',
                    // navigationBarColor: '#00ff00',
                    // 以下两个属性从API Version 8开始支持
                    statusBarContentColor: '#ffffff',
                    navigationBarContentColor: '#ffffff'
                };
                windowClass.setWindowSystemBarProperties(sysBarProps, (err: BusinessError) => {
                    let errCode: number = err.code;
                    if (errCode) {
                        console.error('Failed to set the system bar properties. Cause: ' + JSON.stringify(err));
                        return;
                    }
                    console.info('Succeeded in setting the system bar properties.');
                });
            }
            else if (fullScreenType == 3) {
                windowClass.setFullScreen(true);
            }
        });
    }
    onWindowStageDestroy(): void {
        // Main window is destroyed, release UI related resources
    }
    onForeground(): void {
        // Ability has brought to foreground
        hilog.info(0x0000, 'testTag', '%{public}s', 'Ability onForeground');
    }
    onBackground(): void {
        // Ability has back to background
        hilog.info(0x0000, 'testTag', '%{public}s', 'Ability onBackground');
    }
}
