if (!("finalizeConstruction" in ViewPU.prototype)) {
    Reflect.set(ViewPU.prototype, "finalizeConstruction", () => { });
}
interface LoginTestComponent_Params {
    headSrc?: string | Resource;
    nick?: string;
    isLogin?: boolean;
    forceWebAuth?: boolean;
    useQrcode?: boolean;
    qqOpenApi?: IQQOpenApi;
    accessToken?: string;
    openId?: string;
    // 获取互联用户信息回调
    iuListener?: ApiCallback<string>;
    // 互联授权登录回调监听
    loginListener?: ApiCallback<AuthResponse>;
    onClickAuthBtn?;
}
import { AuthResultType } from "@normalized:N&&&@tencent/qq-open-sdk/Index&1.0.3";
import type { ApiCallback, AuthResponse, AuthResult, IQQOpenApi, UserInfoJson } from "@normalized:N&&&@tencent/qq-open-sdk/Index&1.0.3";
import { QQOpenApiHolder } from "@normalized:N&&&entry/src/main/ets/util/QQOpenApiHolder&";
import hilog from "@ohos:hilog";
import { showDialog, toast } from "@normalized:N&&&entry/src/main/ets/util/AlertUtils&";
import { HttpUtils } from "@normalized:N&&&entry/src/main/ets/util/HttpUtils&";
import type { AccessTokenJson } from "@normalized:N&&&entry/src/main/ets/util/HttpUtils&";
import { PreferenceUtils } from "@normalized:N&&&entry/src/main/ets/util/PreferenceUtils&";
const TAG = 'LoginTestComponent';
export class LoginTestComponent extends ViewPU {
    constructor(parent, params, __localStorage, elmtId = -1, paramsLambda = undefined, extraInfo) {
        super(parent, __localStorage, elmtId, extraInfo);
        if (typeof paramsLambda === "function") {
            this.paramsGenerator_ = paramsLambda;
        }
        this.__headSrc = new ObservedPropertyObjectPU({ "id": 16777217, "type": 20000, params: [], "bundleName": "com.tencent.qqopensdkdemo.db", "moduleName": "entry" }, this, "headSrc");
        this.__nick = new ObservedPropertySimplePU("未登录", this, "nick");
        this.__isLogin = new ObservedPropertySimplePU(false, this, "isLogin");
        this.__forceWebAuth = new ObservedPropertySimplePU(false // 强制使用web页面授权
        , this, "forceWebAuth");
        this.__useQrcode = new ObservedPropertySimplePU(false // 使用扫码授权
        , this, "useQrcode");
        this.qqOpenApi = QQOpenApiHolder.getInstance();
        this.accessToken = "";
        this.openId = "";
        this.iuListener = {
            onComplete: (response: string): void => {
                const json: UserInfoJson = JSON.parse(response);
                hilog.info(0x0000, TAG, "json %{public}s", JSON.stringify(json));
                if (json) {
                    hilog.info(0x0000, TAG, "json ret " + json.ret + ",nick:" + json.nickname + ", figure:" + json.figureurl);
                    if (json.ret == 0 && json.nickname != null && json.figureurl != null) {
                        this.nick = json.nickname;
                        this.headSrc = json.figureurl_qq ?? json.figureurl;
                        this.isLogin = true;
                        return;
                    }
                }
            },
            onError: (msg: string | null): void => {
                if (msg == null || msg.length == 0) {
                    msg = "登录失败";
                }
                this.reset();
                showDialog(msg);
            },
            onCancel: (msg: string | null): void => {
                if (msg == null || msg.length == 0) {
                    msg = "用户取消登录";
                }
                showDialog(msg);
            }
        };
        this.loginListener = {
            onComplete: (response: AuthResponse): void => {
                hilog.info(0x0000, TAG, `onComplete response: ${JSON.stringify(response)}`);
                let authResponse = response;
                if (authResponse.authCode) {
                    HttpUtils.getAccessToken(this.qqOpenApi.appId.toString(), authResponse.authCode)
                        .then((value: AccessTokenJson) => {
                        hilog.info(0x0000, TAG, "code get token : " + JSON.stringify(value));
                        this.getUserInfo(value.access_token, value.openid);
                    }).catch((error: string) => {
                        hilog.info(0x0000, TAG, "code get token error msg: " + error);
                    });
                }
                toast("获取code成功：" + authResponse.authCode);
            },
            onError: (msg: string | null): void => {
                showDialog(`onError msg: ${msg}`);
            },
            onCancel: (msg: string | null): void => {
                showDialog(`onCancel msg: ${msg}`);
            }
        };
        this.onClickAuthBtn = () => {
            // this.testLoginWithPromise();
            this.testLoginWithCallback();
        };
        this.setInitiallyProvidedValue(params);
        this.finalizeConstruction();
    }
    setInitiallyProvidedValue(params: LoginTestComponent_Params) {
        if (params.headSrc !== undefined) {
            this.headSrc = params.headSrc;
        }
        if (params.nick !== undefined) {
            this.nick = params.nick;
        }
        if (params.isLogin !== undefined) {
            this.isLogin = params.isLogin;
        }
        if (params.forceWebAuth !== undefined) {
            this.forceWebAuth = params.forceWebAuth;
        }
        if (params.useQrcode !== undefined) {
            this.useQrcode = params.useQrcode;
        }
        if (params.qqOpenApi !== undefined) {
            this.qqOpenApi = params.qqOpenApi;
        }
        if (params.accessToken !== undefined) {
            this.accessToken = params.accessToken;
        }
        if (params.openId !== undefined) {
            this.openId = params.openId;
        }
        if (params.iuListener !== undefined) {
            this.iuListener = params.iuListener;
        }
        if (params.loginListener !== undefined) {
            this.loginListener = params.loginListener;
        }
        if (params.onClickAuthBtn !== undefined) {
            this.onClickAuthBtn = params.onClickAuthBtn;
        }
    }
    updateStateVars(params: LoginTestComponent_Params) {
    }
    purgeVariableDependenciesOnElmtId(rmElmtId) {
        this.__headSrc.purgeDependencyOnElmtId(rmElmtId);
        this.__nick.purgeDependencyOnElmtId(rmElmtId);
        this.__isLogin.purgeDependencyOnElmtId(rmElmtId);
        this.__forceWebAuth.purgeDependencyOnElmtId(rmElmtId);
        this.__useQrcode.purgeDependencyOnElmtId(rmElmtId);
    }
    aboutToBeDeleted() {
        this.__headSrc.aboutToBeDeleted();
        this.__nick.aboutToBeDeleted();
        this.__isLogin.aboutToBeDeleted();
        this.__forceWebAuth.aboutToBeDeleted();
        this.__useQrcode.aboutToBeDeleted();
        SubscriberManager.Get().delete(this.id__());
        this.aboutToBeDeletedInternal();
    }
    private __headSrc: ObservedPropertyObjectPU<string | Resource>;
    get headSrc() {
        return this.__headSrc.get();
    }
    set headSrc(newValue: string | Resource) {
        this.__headSrc.set(newValue);
    }
    private __nick: ObservedPropertySimplePU<string>;
    get nick() {
        return this.__nick.get();
    }
    set nick(newValue: string) {
        this.__nick.set(newValue);
    }
    private __isLogin: ObservedPropertySimplePU<boolean>;
    get isLogin() {
        return this.__isLogin.get();
    }
    set isLogin(newValue: boolean) {
        this.__isLogin.set(newValue);
    }
    private __forceWebAuth: ObservedPropertySimplePU<boolean>; // 强制使用web页面授权
    get forceWebAuth() {
        return this.__forceWebAuth.get();
    }
    set forceWebAuth(newValue: boolean) {
        this.__forceWebAuth.set(newValue);
    }
    private __useQrcode: ObservedPropertySimplePU<boolean>; // 使用扫码授权
    get useQrcode() {
        return this.__useQrcode.get();
    }
    set useQrcode(newValue: boolean) {
        this.__useQrcode.set(newValue);
    }
    private qqOpenApi: IQQOpenApi;
    private accessToken: string;
    private openId: string;
    // 获取互联用户信息回调
    private iuListener: ApiCallback<string>;
    // 互联授权登录回调监听
    private loginListener: ApiCallback<AuthResponse>;
    aboutToAppear(): void {
        hilog.debug(0x0000, TAG, 'aboutToAppear');
    }
    private getUserInfo(accessToken: string, openId: string) {
        this.qqOpenApi.getUserInfo(accessToken, openId, this.iuListener);
    }
    initialRender() {
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Column.create();
            Column.width("100%");
            Column.height("60%");
            Column.justifyContent(FlexAlign.Center);
            Column.alignItems(HorizontalAlign.Center);
        }, Column);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Row.create({ space: 10, });
            Row.width('80%');
        }, Row);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Image.create(this.headSrc);
            Image.width(60);
            Image.height(60);
            Image.clipShape(new Circle({ width: '100%', height: '100%' }));
            Image.objectFit(ImageFit.Fill);
        }, Image);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Text.create(this.nick);
            Text.baselineOffset(0);
            Text.fontSize(16);
            Text.padding(10);
            Text.textOverflow({ overflow: TextOverflow.Ellipsis });
        }, Text);
        Text.pop();
        Row.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Row.create();
            Row.margin(16);
            Row.visibility(Visibility.None);
        }, Row);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Toggle.create({ type: ToggleType.Checkbox, isOn: false });
        }, Toggle);
        Toggle.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Text.create("用户是否已勾选使用协议");
            Text.height(50);
            Text.fontSize(16);
        }, Text);
        Text.pop();
        Row.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Stack.create();
            Stack.height(116);
        }, Stack);
        Stack.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Row.create();
            Row.width('80%');
            Row.visibility(this.isLogin ? Visibility.Hidden : Visibility.Visible);
        }, Row);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Toggle.create({ type: ToggleType.Checkbox, isOn: this.forceWebAuth });
            Toggle.onChange((isOn) => {
                this.forceWebAuth = isOn;
                if (!isOn) {
                    this.useQrcode = false;
                }
            });
        }, Toggle);
        Toggle.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Text.create("强制使用网页授权");
            Text.fontSize(16);
        }, Text);
        Text.pop();
        Row.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Row.create();
            Row.width('80%');
            Row.visibility(this.isLogin ? Visibility.Hidden : Visibility.Visible);
        }, Row);
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Toggle.create({ type: ToggleType.Checkbox, isOn: this.useQrcode });
            Toggle.onChange((isOn) => {
                this.useQrcode = isOn;
                if (isOn) {
                    this.forceWebAuth = true;
                }
            });
        }, Toggle);
        Toggle.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Text.create("扫码授权(网页授权时生效)");
            Text.fontSize(16);
        }, Text);
        Text.pop();
        Row.pop();
        this.observeComponentCreation2((elmtId, isInitialRender) => {
            Button.createWithLabel(this.isLogin ? "退出登录" : "登录");
            Button.width('80%');
            Button.onClick(() => {
                if (this.isLogin) {
                    this.reset();
                    PreferenceUtils.save(this.qqOpenApi.appId.toString(), '');
                }
                else {
                    this.onClickAuthBtn();
                }
            });
            Button.margin({ top: 16 });
        }, Button);
        Button.pop();
        Column.pop();
    }
    private onClickAuthBtn;
    testLoginWithPromise() {
        this.qqOpenApi.login({
            scope: "all",
            useQrCode: this.useQrcode,
            networkTimeout: 0,
            forceWebLogin: this.forceWebAuth
        })
            .then((result: AuthResult) => {
            hilog.info(0x0000, TAG, "testLoginWithPromise then : " + JSON.stringify(result));
            if (result.type == AuthResultType.Success) {
                let code: string | undefined = result.authResponse?.authCode;
                if (code) {
                    HttpUtils.getAccessToken(this.qqOpenApi.appId.toString(), code)
                        .then((value: AccessTokenJson) => {
                        hilog.info(0x0000, TAG, "code get token : " + JSON.stringify(value));
                        this.getUserInfo(value.access_token, value.openid);
                    }).catch((error: string) => {
                        hilog.info(0x0000, TAG, "code get token error msg: " + error);
                    });
                }
            }
            else if (result.type == AuthResultType.Cancel) {
                showDialog(result.message ?? "");
            }
            else if (result.type == AuthResultType.Error) {
                showDialog(result.message ?? "");
            }
        }).catch(() => {
        });
    }
    testLoginWithCallback() {
        this.qqOpenApi.login({
            scope: "all",
            useQrCode: this.useQrcode,
            networkTimeout: 0,
            forceWebLogin: this.forceWebAuth
        }, this.loginListener);
    }
    reset() {
        this.isLogin = false;
        this.nick = "未登录";
        this.headSrc = { "id": 16777217, "type": 20000, params: [], "bundleName": "com.tencent.qqopensdkdemo.db", "moduleName": "entry" };
        this.accessToken = "";
        this.openId = "";
    }
    rerender() {
        this.updateDirtyElements();
    }
}
