import type { AccessTokenJson } from "./HttpUtils";
import preferences from "@ohos:data.preferences";
import hilog from "@ohos:hilog";
export class PreferenceUtils {
    private static instance = new PreferenceUtils();
    dataPre: preferences.Preferences | null = null;
    private constructor() {
        this.initPreferences();
    }
    private initPreferences() {
        if (!this.dataPre) {
            this.dataPre = preferences.getPreferencesSync(getContext(), { name: "myStore" });
        }
    }
    private static getSp(): preferences.Preferences | null {
        PreferenceUtils.instance.initPreferences();
        return PreferenceUtils.instance.dataPre;
    }
    static save(key: string, data: preferences.ValueType) {
        let preferences = PreferenceUtils.getSp();
        if (preferences) {
            preferences.put(key, data).then(() => {
                preferences?.flush();
            });
        }
        else {
            hilog.debug(0x0000, 'ticketUtils', 'saveTicket: ' + preferences + ", data: " + data);
        }
    }
    static load(key: string, def: preferences.ValueType): preferences.ValueType {
        let preferences = PreferenceUtils.getSp();
        if (preferences) {
            return preferences.getSync(key, def) ?? def;
        }
        else {
            hilog.debug(0x0000, 'ticketUtils', 'load: ' + preferences);
            return def;
        }
    }
    static loadTicket(key: string): AccessTokenJson | null {
        let data = PreferenceUtils.load(key, '');
        if (!data) {
            hilog.debug(0x0000, 'ticketUtils', 'loadTicket: ' + data);
            return null;
        }
        let json = JSON.parse(data as string) as AccessTokenJson;
        hilog.debug(0x0000, 'ticketUtils', 'loadTicket: ' + JSON.stringify(data));
        if (json && !!json.access_token) {
            return json;
        }
        return null;
    }
}
